require 'spec_helper'
require 'secureshare/client'

require 'ostruct'

describe "SecureShare::RestClient" do
    
  let(:rest_client) { double }

  before do
    @client = SecureShare::Client.new 'http://example.com', '12345', 'http://app.com'
    @client.rest_client = rest_client
  end

  def headers
    {:authorization => %{Token token="12345"}, :content_type => :json, :accept => :json}
  end

  describe "fetching a vault" do
    it "invokes RestClient correctly" do
      rest_client.should_receive(:get).with("http://example.com/api/v1/vaults/abc", headers).and_return(FakeResponse.new({"some" => "json"}))
      @client.fetch_vault('abc').should == {'some' => 'json'}
    end
  end

  describe "following a vault" do
    describe 'when there are no validation errors' do
      it 'returns empty json' do
        rest_client.should_receive(:post).with("http://example.com/api/v1/vaults/abc/follow",{email: 'a@b.com', site_name: 'http://app.com'}, headers).and_return(OpenStruct.new(body: '{}', code: 200))
        @client.follow_vault('abc', 'a@b.com').should == {}
      end
    end

    describe 'when the email is already registered' do 
      it 'raises a SecureShare::RestException' do
        rest_client.should_receive(:post).with("http://example.com/api/v1/vaults/abc/follow",{email: 'a@b.com', site_name: 'http://app.com'}, headers).and_raise(RestClient::UnprocessableEntity.new(OpenStruct.new(body: '{"email": "is already registered"}', code: 422)))
        begin
          @client.follow_vault('abc', 'a@b.com')
        rescue SecureShare::RestException => e
          e.field.should == "email"
          e.message.should == "is already registered"
        end
      end
    end
  end
end